====================================
Client interface for Scrapinghub API
====================================

.. image:: https://img.shields.io/pypi/v/scrapinghub.svg
   :target: https://pypi.org/project/scrapinghub

.. image:: https://img.shields.io/pypi/pyversions/scrapinghub.svg
   :target: https://pypi.org/project/scrapinghub

.. image:: https://github.com/scrapinghub/python-scrapinghub/actions/workflows/main.yml/badge.svg
   :target: https://github.com/scrapinghub/python-scrapinghub/actions/workflows/main.yml

.. image:: https://codecov.io/gh/scrapinghub/python-scrapinghub/branch/master/graph/badge.svg
   :target: https://app.codecov.io/gh/scrapinghub/python-scrapinghub

The ``scrapinghub`` is a Python library for communicating with the `Scrapinghub API`_.


Requirements
============

* Python 2.7 or Python 3.5+


Installation
============

The quick way::

    pip install scrapinghub

You can also install the library with MessagePack support, it provides better
response time and improved bandwidth usage::

    pip install scrapinghub[msgpack]


Documentation
-------------

Documentation is `available online`_ via Read the Docs or in the ``docs`` directory.


.. _Scrapinghub API: https://doc.scrapinghub.com/scrapy-cloud.html#scrapycloud
.. _available online: https://python-scrapinghub.readthedocs.io/
